==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/ctimertick.h <==
/***************************************************************************
                         ctimertick.h  -  description
                             -------------------
    begin                : ?t mj 8 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@host.sk
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CTIMERTICK_H
#define CTIMERTICK_H

#include "ctimer.h"

class cSession;

/**
Tick timer.
  *@author Marco Mastroddi
  */

class cTimerTick : public cTimer  {

public:
  cTimerTick (cSession *s);
  ~cTimerTick ();

  virtual QString performAction ();
  
  virtual int itemType () { return TYPE_TIMERTICK; };
  /** creates a new instance of the class */
  virtual cSaveableField *newInstance ();

  virtual void tick (int tickTime);

  /** load data from a config file*/
  virtual void load (KConfig *config, const QString &);
  /** save data to a config file*/
  virtual void save (KConfig *config, const QString &);

  void setTimeoutMargin (int what) { _timeoutmargin = what; }
  int timeoutMargin() const { return _timeoutmargin; }

  int countdown() const { return _countdown; }

protected:
  int _timeoutmargin;
  int _countdown;

};

#endif

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/ctimertick.h <==
/***************************************************************************
                         ctimertick.h  -  description
                             -------------------
    begin                : ?t mj 8 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CTIMERTICK_H
#define CTIMERTICK_H

#include "ctimer.h"

/**
Tick timer.
  *@author Marco Mastroddi
  */

class cTimerTick : public cTimer  {

public:
  cTimerTick (int _sess);
  ~cTimerTick ();

  virtual QString performAction ();
  
  virtual int itemType () { return TYPE_TIMERTICK; };
  /** creates a new instance of the class */
  virtual cSaveableField *newInstance ();

  virtual void tick (int tickTime);

  /** load data from a config file*/
  virtual void load (KConfig *config, const QString &);
  /** save data to a config file*/
  virtual void save (KConfig *config, const QString &);

  void setTimeoutMargin (int what) { _timeoutmargin = what; }
  int timeoutMargin() const { return _timeoutmargin; }

  int countdown() const { return _countdown; }

protected:
  int _timeoutmargin;
  int _countdown;

};

#endif
